@@ -14,7 +14,7 @@ GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
-Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */
 
 #ifndef msfilter_h
@@ -61,7 +61,7 @@ typedef int (*MSFilterMethodFunc)(struct _MSFilter *f, void *arg);
 typedef void (*MSFilterNotifyFunc)(void *userdata, struct _MSFilter *f, unsigned int id, void *arg);
 
 struct _MSFilterMethod{
-	int id;
+	unsigned int id;
 	MSFilterMethodFunc method;
 };
 
@@ -246,6 +246,8 @@ extern "C"{
  */
 MS2_PUBLIC MS2_DEPRECATED void ms_filter_register(MSFilterDesc *desc);
 
+
+
 /**
  * Retrieve capture filter that supports encoding to codec name.
  *
@@ -450,19 +452,6 @@ MS2_PUBLIC bool_t ms_filter_implements_interface(MSFilter *f, MSFilterInterfaceI
 **/
 MS2_PUBLIC bool_t ms_filter_desc_implements_interface(MSFilterDesc *desc, MSFilterInterfaceId id);
 
-/**
- * Set a callback on filter's to be informed of private filter's event.
- * This callback is called from the filter's MSTicker, unless a global event queue
- * is created to receive all filter's notification asynchronously.
- * See ms_event_queue_new() for details.
- *
- * @param f        A MSFilter object.
- * @param fn       A MSFilterNotifyFunc that will be called.
- * @param userdata A pointer to private data.
- * @deprecated use ms_filter_add_notify_callback()
- *
- */
-
 
 /**
  * Set a callback on filter's to be informed of private filter's event.
